You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by se...@apache.org on 2011/04/13 15:59:33 UTC

svn commit: r1091783 - /commons/proper/net/trunk/src/main/java/org/apache/commons/net/ftp/FTPSClient.java

Author: sebb
Date: Wed Apr 13 13:59:32 2011
New Revision: 1091783

URL: http://svn.apache.org/viewvc?rev=1091783&view=rev
Log:
Revert to previous permissive trust manager.

Modified:
    commons/proper/net/trunk/src/main/java/org/apache/commons/net/ftp/FTPSClient.java

Modified: commons/proper/net/trunk/src/main/java/org/apache/commons/net/ftp/FTPSClient.java
URL: http://svn.apache.org/viewvc/commons/proper/net/trunk/src/main/java/org/apache/commons/net/ftp/FTPSClient.java?rev=1091783&r1=1091782&r2=1091783&view=diff
==============================================================================
--- commons/proper/net/trunk/src/main/java/org/apache/commons/net/ftp/FTPSClient.java (original)
+++ commons/proper/net/trunk/src/main/java/org/apache/commons/net/ftp/FTPSClient.java Wed Apr 13 13:59:32 2011
@@ -32,6 +32,7 @@ import javax.net.ssl.TrustManager;
 
 import org.apache.commons.net.util.Base64;
 import org.apache.commons.net.util.SSLContextUtils;
+import org.apache.commons.net.util.TrustManagerUtils;
 
 /**
  * FTP over SSL processing. If desired, the JVM property -Djavax.net.debug=all can be used to
@@ -99,8 +100,8 @@ public class FTPSClient extends FTPClien
     /** The protocol versions */
     private String[] protocols = null;
 
-    /** The FTPS {@link TrustManager} implementation, default null (i.e. use system default). */
-    private TrustManager trustManager = null;
+    /** The FTPS {@link TrustManager} implementation, default validate only: {@link TrustManagerUtils#getValidateServerCertificateTrustManager()}. */
+    private TrustManager trustManager = TrustManagerUtils.getValidateServerCertificateTrustManager();
 
     /** The {@link KeyManager}, default null (i.e. use system default). */
     private KeyManager keyManager = null;